@@ -243,7 +243,7 @@ namespace TagLib {
       class ChapterFramePrivate;
       ChapterFramePrivate *d;
     };
-  }
-}
+  }  // namespace ID3v2
+}  // namespace TagLib
 
 #endif
